=======
History
=======

0.1.0 (2021-03-11)
------------------

* First release on PyPI.

0.1.1 (2021-05-18)
------------------

* Decouple from `pg_config` requirement (now using `psycopg2-binary`, which while less than ideal, can run in zee clouds)
* Dependency updates for security vulns
* Companies House API
